@@ -2,105 +2,30 @@ import terrascript.core as core
 
 
 @core.schema
-class ClientPolicyTlsValidationTrustFile(core.Schema):
+class PortMapping(core.Schema):
 
-    certificate_chain: str | core.StringOut = core.attr(str)
+    port: int | core.IntOut = core.attr(int)
+
+    protocol: str | core.StringOut = core.attr(str)
 
     def __init__(
         self,
         *,
-        certificate_chain: str | core.StringOut,
+        port: int | core.IntOut,
+        protocol: str | core.StringOut,
     ):
         super().__init__(
-            args=ClientPolicyTlsValidationTrustFile.Args(
-                certificate_chain=certificate_chain,
+            args=PortMapping.Args(
+                port=port,
+                protocol=protocol,
             ),
         )
 
     @core.schema_args
     class Args(core.SchemaArgs):
-        certificate_chain: str | core.StringOut = core.arg()
+        port: int | core.IntOut = core.arg()
 
-
-@core.schema
-class Sds(core.Schema):
-
-    secret_name: str | core.StringOut = core.attr(str)
-
-    def __init__(
-        self,
-        *,
-        secret_name: str | core.StringOut,
-    ):
-        super().__init__(
-            args=Sds.Args(
-                secret_name=secret_name,
-            ),
-        )
-
-    @core.schema_args
-    class Args(core.SchemaArgs):
-        secret_name: str | core.StringOut = core.arg()
-
-
-@core.schema
-class ClientPolicyTlsValidationTrustAcm(core.Schema):
-
-    certificate_authority_arns: list[str] | core.ArrayOut[core.StringOut] = core.attr(
-        str, kind=core.Kind.array
-    )
-
-    def __init__(
-        self,
-        *,
-        certificate_authority_arns: list[str] | core.ArrayOut[core.StringOut],
-    ):
-        super().__init__(
-            args=ClientPolicyTlsValidationTrustAcm.Args(
-                certificate_authority_arns=certificate_authority_arns,
-            ),
-        )
-
-    @core.schema_args
-    class Args(core.SchemaArgs):
-        certificate_authority_arns: list[str] | core.ArrayOut[core.StringOut] = core.arg()
-
-
-@core.schema
-class ClientPolicyTlsValidationTrust(core.Schema):
-
-    acm: ClientPolicyTlsValidationTrustAcm | None = core.attr(
-        ClientPolicyTlsValidationTrustAcm, default=None
-    )
-
-    file: ClientPolicyTlsValidationTrustFile | None = core.attr(
-        ClientPolicyTlsValidationTrustFile, default=None
-    )
-
-    sds: Sds | None = core.attr(Sds, default=None)
-
-    def __init__(
-        self,
-        *,
-        acm: ClientPolicyTlsValidationTrustAcm | None = None,
-        file: ClientPolicyTlsValidationTrustFile | None = None,
-        sds: Sds | None = None,
-    ):
-        super().__init__(
-            args=ClientPolicyTlsValidationTrust.Args(
-                acm=acm,
-                file=file,
-                sds=sds,
-            ),
-        )
-
-    @core.schema_args
-    class Args(core.SchemaArgs):
-        acm: ClientPolicyTlsValidationTrustAcm | None = core.arg(default=None)
-
-        file: ClientPolicyTlsValidationTrustFile | None = core.arg(default=None)
-
-        sds: Sds | None = core.arg(default=None)
+        protocol: str | core.StringOut = core.arg()
 
 
 @core.schema
@@ -146,51 +71,18 @@ class SubjectAlternativeNames(core.Schema):
 
 
 @core.schema
-class ClientPolicyTlsValidation(core.Schema):
-
-    subject_alternative_names: SubjectAlternativeNames | None = core.attr(
-        SubjectAlternativeNames, default=None
-    )
-
-    trust: ClientPolicyTlsValidationTrust = core.attr(ClientPolicyTlsValidationTrust)
-
-    def __init__(
-        self,
-        *,
-        trust: ClientPolicyTlsValidationTrust,
-        subject_alternative_names: SubjectAlternativeNames | None = None,
-    ):
-        super().__init__(
-            args=ClientPolicyTlsValidation.Args(
-                trust=trust,
-                subject_alternative_names=subject_alternative_names,
-            ),
-        )
-
-    @core.schema_args
-    class Args(core.SchemaArgs):
-        subject_alternative_names: SubjectAlternativeNames | None = core.arg(default=None)
-
-        trust: ClientPolicyTlsValidationTrust = core.arg()
-
-
-@core.schema
-class ClientPolicyTlsCertificateFile(core.Schema):
+class ListenerTlsValidationTrustFile(core.Schema):
 
     certificate_chain: str | core.StringOut = core.attr(str)
 
-    private_key: str | core.StringOut = core.attr(str)
-
     def __init__(
         self,
         *,
         certificate_chain: str | core.StringOut,
-        private_key: str | core.StringOut,
     ):
         super().__init__(
-            args=ClientPolicyTlsCertificateFile.Args(
+            args=ListenerTlsValidationTrustFile.Args(
                 certificate_chain=certificate_chain,
-                private_key=private_key,
             ),
         )
 
@@ -198,184 +90,33 @@ class ClientPolicyTlsCertificateFile(core.Schema):
     class Args(core.SchemaArgs):
         certificate_chain: str | core.StringOut = core.arg()
 
-        private_key: str | core.StringOut = core.arg()
-
 
 @core.schema
-class ClientPolicyTlsCertificate(core.Schema):
+class Sds(core.Schema):
 
-    file: ClientPolicyTlsCertificateFile | None = core.attr(
-        ClientPolicyTlsCertificateFile, default=None
-    )
-
-    sds: Sds | None = core.attr(Sds, default=None)
+    secret_name: str | core.StringOut = core.attr(str)
 
     def __init__(
         self,
         *,
-        file: ClientPolicyTlsCertificateFile | None = None,
-        sds: Sds | None = None,
+        secret_name: str | core.StringOut,
     ):
         super().__init__(
-            args=ClientPolicyTlsCertificate.Args(
-                file=file,
-                sds=sds,
+            args=Sds.Args(
+                secret_name=secret_name,
             ),
         )
 
     @core.schema_args
     class Args(core.SchemaArgs):
-        file: ClientPolicyTlsCertificateFile | None = core.arg(default=None)
-
-        sds: Sds | None = core.arg(default=None)
-
-
-@core.schema
-class ClientPolicyTls(core.Schema):
-
-    certificate: ClientPolicyTlsCertificate | None = core.attr(
-        ClientPolicyTlsCertificate, default=None
-    )
-
-    enforce: bool | core.BoolOut | None = core.attr(bool, default=None)
-
-    ports: list[int] | core.ArrayOut[core.IntOut] | None = core.attr(
-        int, default=None, kind=core.Kind.array
-    )
-
-    validation: ClientPolicyTlsValidation = core.attr(ClientPolicyTlsValidation)
-
-    def __init__(
-        self,
-        *,
-        validation: ClientPolicyTlsValidation,
-        certificate: ClientPolicyTlsCertificate | None = None,
-        enforce: bool | core.BoolOut | None = None,
-        ports: list[int] | core.ArrayOut[core.IntOut] | None = None,
-    ):
-        super().__init__(
-            args=ClientPolicyTls.Args(
-                validation=validation,
-                certificate=certificate,
-                enforce=enforce,
-                ports=ports,
-            ),
-        )
-
-    @core.schema_args
-    class Args(core.SchemaArgs):
-        certificate: ClientPolicyTlsCertificate | None = core.arg(default=None)
-
-        enforce: bool | core.BoolOut | None = core.arg(default=None)
-
-        ports: list[int] | core.ArrayOut[core.IntOut] | None = core.arg(default=None)
-
-        validation: ClientPolicyTlsValidation = core.arg()
-
-
-@core.schema
-class ClientPolicy(core.Schema):
-
-    tls: ClientPolicyTls | None = core.attr(ClientPolicyTls, default=None)
-
-    def __init__(
-        self,
-        *,
-        tls: ClientPolicyTls | None = None,
-    ):
-        super().__init__(
-            args=ClientPolicy.Args(
-                tls=tls,
-            ),
-        )
-
-    @core.schema_args
-    class Args(core.SchemaArgs):
-        tls: ClientPolicyTls | None = core.arg(default=None)
-
-
-@core.schema
-class BackendDefaults(core.Schema):
-
-    client_policy: ClientPolicy | None = core.attr(ClientPolicy, default=None)
-
-    def __init__(
-        self,
-        *,
-        client_policy: ClientPolicy | None = None,
-    ):
-        super().__init__(
-            args=BackendDefaults.Args(
-                client_policy=client_policy,
-            ),
-        )
-
-    @core.schema_args
-    class Args(core.SchemaArgs):
-        client_policy: ClientPolicy | None = core.arg(default=None)
-
-
-@core.schema
-class ListenerTlsCertificateAcm(core.Schema):
-
-    certificate_arn: str | core.StringOut = core.attr(str)
-
-    def __init__(
-        self,
-        *,
-        certificate_arn: str | core.StringOut,
-    ):
-        super().__init__(
-            args=ListenerTlsCertificateAcm.Args(
-                certificate_arn=certificate_arn,
-            ),
-        )
-
-    @core.schema_args
-    class Args(core.SchemaArgs):
-        certificate_arn: str | core.StringOut = core.arg()
-
-
-@core.schema
-class ListenerTlsCertificate(core.Schema):
-
-    acm: ListenerTlsCertificateAcm | None = core.attr(ListenerTlsCertificateAcm, default=None)
-
-    file: ClientPolicyTlsCertificateFile | None = core.attr(
-        ClientPolicyTlsCertificateFile, default=None
-    )
-
-    sds: Sds | None = core.attr(Sds, default=None)
-
-    def __init__(
-        self,
-        *,
-        acm: ListenerTlsCertificateAcm | None = None,
-        file: ClientPolicyTlsCertificateFile | None = None,
-        sds: Sds | None = None,
-    ):
-        super().__init__(
-            args=ListenerTlsCertificate.Args(
-                acm=acm,
-                file=file,
-                sds=sds,
-            ),
-        )
-
-    @core.schema_args
-    class Args(core.SchemaArgs):
-        acm: ListenerTlsCertificateAcm | None = core.arg(default=None)
-
-        file: ClientPolicyTlsCertificateFile | None = core.arg(default=None)
-
-        sds: Sds | None = core.arg(default=None)
+        secret_name: str | core.StringOut = core.arg()
 
 
 @core.schema
 class ListenerTlsValidationTrust(core.Schema):
 
-    file: ClientPolicyTlsValidationTrustFile | None = core.attr(
-        ClientPolicyTlsValidationTrustFile, default=None
+    file: ListenerTlsValidationTrustFile | None = core.attr(
+        ListenerTlsValidationTrustFile, default=None
     )
 
     sds: Sds | None = core.attr(Sds, default=None)
@@ -383,7 +124,7 @@ class ListenerTlsValidationTrust(core.Schema):
     def __init__(
         self,
         *,
-        file: ClientPolicyTlsValidationTrustFile | None = None,
+        file: ListenerTlsValidationTrustFile | None = None,
         sds: Sds | None = None,
     ):
         super().__init__(
@@ -395,7 +136,7 @@ class ListenerTlsValidationTrust(core.Schema):
 
     @core.schema_args
     class Args(core.SchemaArgs):
-        file: ClientPolicyTlsValidationTrustFile | None = core.arg(default=None)
+        file: ListenerTlsValidationTrustFile | None = core.arg(default=None)
 
         sds: Sds | None = core.arg(default=None)
 
@@ -429,6 +170,87 @@ class ListenerTlsValidation(core.Schema):
         trust: ListenerTlsValidationTrust = core.arg()
 
 
+@core.schema
+class ListenerTlsCertificateAcm(core.Schema):
+
+    certificate_arn: str | core.StringOut = core.attr(str)
+
+    def __init__(
+        self,
+        *,
+        certificate_arn: str | core.StringOut,
+    ):
+        super().__init__(
+            args=ListenerTlsCertificateAcm.Args(
+                certificate_arn=certificate_arn,
+            ),
+        )
+
+    @core.schema_args
+    class Args(core.SchemaArgs):
+        certificate_arn: str | core.StringOut = core.arg()
+
+
+@core.schema
+class ListenerTlsCertificateFile(core.Schema):
+
+    certificate_chain: str | core.StringOut = core.attr(str)
+
+    private_key: str | core.StringOut = core.attr(str)
+
+    def __init__(
+        self,
+        *,
+        certificate_chain: str | core.StringOut,
+        private_key: str | core.StringOut,
+    ):
+        super().__init__(
+            args=ListenerTlsCertificateFile.Args(
+                certificate_chain=certificate_chain,
+                private_key=private_key,
+            ),
+        )
+
+    @core.schema_args
+    class Args(core.SchemaArgs):
+        certificate_chain: str | core.StringOut = core.arg()
+
+        private_key: str | core.StringOut = core.arg()
+
+
+@core.schema
+class ListenerTlsCertificate(core.Schema):
+
+    acm: ListenerTlsCertificateAcm | None = core.attr(ListenerTlsCertificateAcm, default=None)
+
+    file: ListenerTlsCertificateFile | None = core.attr(ListenerTlsCertificateFile, default=None)
+
+    sds: Sds | None = core.attr(Sds, default=None)
+
+    def __init__(
+        self,
+        *,
+        acm: ListenerTlsCertificateAcm | None = None,
+        file: ListenerTlsCertificateFile | None = None,
+        sds: Sds | None = None,
+    ):
+        super().__init__(
+            args=ListenerTlsCertificate.Args(
+                acm=acm,
+                file=file,
+                sds=sds,
+            ),
+        )
+
+    @core.schema_args
+    class Args(core.SchemaArgs):
+        acm: ListenerTlsCertificateAcm | None = core.arg(default=None)
+
+        file: ListenerTlsCertificateFile | None = core.arg(default=None)
+
+        sds: Sds | None = core.arg(default=None)
+
+
 @core.schema
 class ListenerTls(core.Schema):
 
@@ -462,27 +284,6 @@ class ListenerTls(core.Schema):
         validation: ListenerTlsValidation | None = core.arg(default=None)
 
 
-@core.schema
-class Grpc(core.Schema):
-
-    max_requests: int | core.IntOut = core.attr(int)
-
-    def __init__(
-        self,
-        *,
-        max_requests: int | core.IntOut,
-    ):
-        super().__init__(
-            args=Grpc.Args(
-                max_requests=max_requests,
-            ),
-        )
-
-    @core.schema_args
-    class Args(core.SchemaArgs):
-        max_requests: int | core.IntOut = core.arg()
-
-
 @core.schema
 class Http(core.Schema):
 
@@ -531,6 +332,27 @@ class Http2(core.Schema):
         max_requests: int | core.IntOut = core.arg()
 
 
+@core.schema
+class Grpc(core.Schema):
+
+    max_requests: int | core.IntOut = core.attr(int)
+
+    def __init__(
+        self,
+        *,
+        max_requests: int | core.IntOut,
+    ):
+        super().__init__(
+            args=Grpc.Args(
+                max_requests=max_requests,
+            ),
+        )
+
+    @core.schema_args
+    class Args(core.SchemaArgs):
+        max_requests: int | core.IntOut = core.arg()
+
+
 @core.schema
 class ConnectionPool(core.Schema):
 
@@ -621,33 +443,6 @@ class HealthCheck(core.Schema):
         unhealthy_threshold: int | core.IntOut = core.arg()
 
 
-@core.schema
-class PortMapping(core.Schema):
-
-    port: int | core.IntOut = core.attr(int)
-
-    protocol: str | core.StringOut = core.attr(str)
-
-    def __init__(
-        self,
-        *,
-        port: int | core.IntOut,
-        protocol: str | core.StringOut,
-    ):
-        super().__init__(
-            args=PortMapping.Args(
-                port=port,
-                protocol=protocol,
-            ),
-        )
-
-    @core.schema_args
-    class Args(core.SchemaArgs):
-        port: int | core.IntOut = core.arg()
-
-        protocol: str | core.StringOut = core.arg()
-
-
 @core.schema
 class Listener(core.Schema):
 
@@ -750,6 +545,207 @@ class Logging(core.Schema):
         access_log: AccessLog | None = core.arg(default=None)
 
 
+@core.schema
+class ClientPolicyTlsValidationTrustAcm(core.Schema):
+
+    certificate_authority_arns: list[str] | core.ArrayOut[core.StringOut] = core.attr(
+        str, kind=core.Kind.array
+    )
+
+    def __init__(
+        self,
+        *,
+        certificate_authority_arns: list[str] | core.ArrayOut[core.StringOut],
+    ):
+        super().__init__(
+            args=ClientPolicyTlsValidationTrustAcm.Args(
+                certificate_authority_arns=certificate_authority_arns,
+            ),
+        )
+
+    @core.schema_args
+    class Args(core.SchemaArgs):
+        certificate_authority_arns: list[str] | core.ArrayOut[core.StringOut] = core.arg()
+
+
+@core.schema
+class ClientPolicyTlsValidationTrust(core.Schema):
+
+    acm: ClientPolicyTlsValidationTrustAcm | None = core.attr(
+        ClientPolicyTlsValidationTrustAcm, default=None
+    )
+
+    file: ListenerTlsValidationTrustFile | None = core.attr(
+        ListenerTlsValidationTrustFile, default=None
+    )
+
+    sds: Sds | None = core.attr(Sds, default=None)
+
+    def __init__(
+        self,
+        *,
+        acm: ClientPolicyTlsValidationTrustAcm | None = None,
+        file: ListenerTlsValidationTrustFile | None = None,
+        sds: Sds | None = None,
+    ):
+        super().__init__(
+            args=ClientPolicyTlsValidationTrust.Args(
+                acm=acm,
+                file=file,
+                sds=sds,
+            ),
+        )
+
+    @core.schema_args
+    class Args(core.SchemaArgs):
+        acm: ClientPolicyTlsValidationTrustAcm | None = core.arg(default=None)
+
+        file: ListenerTlsValidationTrustFile | None = core.arg(default=None)
+
+        sds: Sds | None = core.arg(default=None)
+
+
+@core.schema
+class ClientPolicyTlsValidation(core.Schema):
+
+    subject_alternative_names: SubjectAlternativeNames | None = core.attr(
+        SubjectAlternativeNames, default=None
+    )
+
+    trust: ClientPolicyTlsValidationTrust = core.attr(ClientPolicyTlsValidationTrust)
+
+    def __init__(
+        self,
+        *,
+        trust: ClientPolicyTlsValidationTrust,
+        subject_alternative_names: SubjectAlternativeNames | None = None,
+    ):
+        super().__init__(
+            args=ClientPolicyTlsValidation.Args(
+                trust=trust,
+                subject_alternative_names=subject_alternative_names,
+            ),
+        )
+
+    @core.schema_args
+    class Args(core.SchemaArgs):
+        subject_alternative_names: SubjectAlternativeNames | None = core.arg(default=None)
+
+        trust: ClientPolicyTlsValidationTrust = core.arg()
+
+
+@core.schema
+class ClientPolicyTlsCertificate(core.Schema):
+
+    file: ListenerTlsCertificateFile | None = core.attr(ListenerTlsCertificateFile, default=None)
+
+    sds: Sds | None = core.attr(Sds, default=None)
+
+    def __init__(
+        self,
+        *,
+        file: ListenerTlsCertificateFile | None = None,
+        sds: Sds | None = None,
+    ):
+        super().__init__(
+            args=ClientPolicyTlsCertificate.Args(
+                file=file,
+                sds=sds,
+            ),
+        )
+
+    @core.schema_args
+    class Args(core.SchemaArgs):
+        file: ListenerTlsCertificateFile | None = core.arg(default=None)
+
+        sds: Sds | None = core.arg(default=None)
+
+
+@core.schema
+class ClientPolicyTls(core.Schema):
+
+    certificate: ClientPolicyTlsCertificate | None = core.attr(
+        ClientPolicyTlsCertificate, default=None
+    )
+
+    enforce: bool | core.BoolOut | None = core.attr(bool, default=None)
+
+    ports: list[int] | core.ArrayOut[core.IntOut] | None = core.attr(
+        int, default=None, kind=core.Kind.array
+    )
+
+    validation: ClientPolicyTlsValidation = core.attr(ClientPolicyTlsValidation)
+
+    def __init__(
+        self,
+        *,
+        validation: ClientPolicyTlsValidation,
+        certificate: ClientPolicyTlsCertificate | None = None,
+        enforce: bool | core.BoolOut | None = None,
+        ports: list[int] | core.ArrayOut[core.IntOut] | None = None,
+    ):
+        super().__init__(
+            args=ClientPolicyTls.Args(
+                validation=validation,
+                certificate=certificate,
+                enforce=enforce,
+                ports=ports,
+            ),
+        )
+
+    @core.schema_args
+    class Args(core.SchemaArgs):
+        certificate: ClientPolicyTlsCertificate | None = core.arg(default=None)
+
+        enforce: bool | core.BoolOut | None = core.arg(default=None)
+
+        ports: list[int] | core.ArrayOut[core.IntOut] | None = core.arg(default=None)
+
+        validation: ClientPolicyTlsValidation = core.arg()
+
+
+@core.schema
+class ClientPolicy(core.Schema):
+
+    tls: ClientPolicyTls | None = core.attr(ClientPolicyTls, default=None)
+
+    def __init__(
+        self,
+        *,
+        tls: ClientPolicyTls | None = None,
+    ):
+        super().__init__(
+            args=ClientPolicy.Args(
+                tls=tls,
+            ),
+        )
+
+    @core.schema_args
+    class Args(core.SchemaArgs):
+        tls: ClientPolicyTls | None = core.arg(default=None)
+
+
+@core.schema
+class BackendDefaults(core.Schema):
+
+    client_policy: ClientPolicy | None = core.attr(ClientPolicy, default=None)
+
+    def __init__(
+        self,
+        *,
+        client_policy: ClientPolicy | None = None,
+    ):
+        super().__init__(
+            args=BackendDefaults.Args(
+                client_policy=client_policy,
+            ),
+        )
+
+    @core.schema_args
+    class Args(core.SchemaArgs):
+        client_policy: ClientPolicy | None = core.arg(default=None)
+
+
 @core.schema
 class Spec(core.Schema):
 
