@@ -2,36 +2,24 @@ import terrascript.core as core
 
 
 @core.schema
-class VisibilityConfig(core.Schema):
+class RuleLabel(core.Schema):
 
-    cloudwatch_metrics_enabled: bool | core.BoolOut = core.attr(bool)
-
-    metric_name: str | core.StringOut = core.attr(str)
-
-    sampled_requests_enabled: bool | core.BoolOut = core.attr(bool)
+    name: str | core.StringOut = core.attr(str)
 
     def __init__(
         self,
         *,
-        cloudwatch_metrics_enabled: bool | core.BoolOut,
-        metric_name: str | core.StringOut,
-        sampled_requests_enabled: bool | core.BoolOut,
+        name: str | core.StringOut,
     ):
         super().__init__(
-            args=VisibilityConfig.Args(
-                cloudwatch_metrics_enabled=cloudwatch_metrics_enabled,
-                metric_name=metric_name,
-                sampled_requests_enabled=sampled_requests_enabled,
+            args=RuleLabel.Args(
+                name=name,
             ),
         )
 
     @core.schema_args
     class Args(core.SchemaArgs):
-        cloudwatch_metrics_enabled: bool | core.BoolOut = core.arg()
-
-        metric_name: str | core.StringOut = core.arg()
-
-        sampled_requests_enabled: bool | core.BoolOut = core.arg()
+        name: str | core.StringOut = core.arg()
 
 
 @core.schema
@@ -115,6 +103,24 @@ class LabelMatchStatement(core.Schema):
         scope: str | core.StringOut = core.arg()
 
 
+@core.schema
+class AllQueryArguments(core.Schema):
+    ...
+
+    @core.schema_args
+    class Args(core.SchemaArgs):
+        ...
+
+
+@core.schema
+class Body(core.Schema):
+    ...
+
+    @core.schema_args
+    class Args(core.SchemaArgs):
+        ...
+
+
 @core.schema
 class Method(core.Schema):
     ...
@@ -184,24 +190,6 @@ class UriPath(core.Schema):
         ...
 
 
-@core.schema
-class AllQueryArguments(core.Schema):
-    ...
-
-    @core.schema_args
-    class Args(core.SchemaArgs):
-        ...
-
-
-@core.schema
-class Body(core.Schema):
-    ...
-
-    @core.schema_args
-    class Args(core.SchemaArgs):
-        ...
-
-
 @core.schema
 class FieldToMatch(core.Schema):
 
@@ -287,13 +275,13 @@ class TextTransformation(core.Schema):
 
 
 @core.schema
-class SizeConstraintStatement(core.Schema):
-
-    comparison_operator: str | core.StringOut = core.attr(str)
+class ByteMatchStatement(core.Schema):
 
     field_to_match: FieldToMatch | None = core.attr(FieldToMatch, default=None)
 
-    size: int | core.IntOut = core.attr(int)
+    positional_constraint: str | core.StringOut = core.attr(str)
+
+    search_string: str | core.StringOut = core.attr(str)
 
     text_transformation: list[TextTransformation] | core.ArrayOut[TextTransformation] = core.attr(
         TextTransformation, kind=core.Kind.array
@@ -302,15 +290,15 @@ class SizeConstraintStatement(core.Schema):
     def __init__(
         self,
         *,
-        comparison_operator: str | core.StringOut,
-        size: int | core.IntOut,
+        positional_constraint: str | core.StringOut,
+        search_string: str | core.StringOut,
         text_transformation: list[TextTransformation] | core.ArrayOut[TextTransformation],
         field_to_match: FieldToMatch | None = None,
     ):
         super().__init__(
-            args=SizeConstraintStatement.Args(
-                comparison_operator=comparison_operator,
-                size=size,
+            args=ByteMatchStatement.Args(
+                positional_constraint=positional_constraint,
+                search_string=search_string,
                 text_transformation=text_transformation,
                 field_to_match=field_to_match,
             ),
@@ -318,11 +306,11 @@ class SizeConstraintStatement(core.Schema):
 
     @core.schema_args
     class Args(core.SchemaArgs):
-        comparison_operator: str | core.StringOut = core.arg()
-
         field_to_match: FieldToMatch | None = core.arg(default=None)
 
-        size: int | core.IntOut = core.arg()
+        positional_constraint: str | core.StringOut = core.arg()
+
+        search_string: str | core.StringOut = core.arg()
 
         text_transformation: list[TextTransformation] | core.ArrayOut[
             TextTransformation
@@ -391,37 +379,6 @@ class IpSetReferenceStatement(core.Schema):
         ip_set_forwarded_ip_config: IpSetForwardedIpConfig | None = core.arg(default=None)
 
 
-@core.schema
-class XssMatchStatement(core.Schema):
-
-    field_to_match: FieldToMatch | None = core.attr(FieldToMatch, default=None)
-
-    text_transformation: list[TextTransformation] | core.ArrayOut[TextTransformation] = core.attr(
-        TextTransformation, kind=core.Kind.array
-    )
-
-    def __init__(
-        self,
-        *,
-        text_transformation: list[TextTransformation] | core.ArrayOut[TextTransformation],
-        field_to_match: FieldToMatch | None = None,
-    ):
-        super().__init__(
-            args=XssMatchStatement.Args(
-                text_transformation=text_transformation,
-                field_to_match=field_to_match,
-            ),
-        )
-
-    @core.schema_args
-    class Args(core.SchemaArgs):
-        field_to_match: FieldToMatch | None = core.arg(default=None)
-
-        text_transformation: list[TextTransformation] | core.ArrayOut[
-            TextTransformation
-        ] = core.arg()
-
-
 @core.schema
 class RegexPatternSetReferenceStatement(core.Schema):
 
@@ -459,6 +416,49 @@ class RegexPatternSetReferenceStatement(core.Schema):
         ] = core.arg()
 
 
+@core.schema
+class SizeConstraintStatement(core.Schema):
+
+    comparison_operator: str | core.StringOut = core.attr(str)
+
+    field_to_match: FieldToMatch | None = core.attr(FieldToMatch, default=None)
+
+    size: int | core.IntOut = core.attr(int)
+
+    text_transformation: list[TextTransformation] | core.ArrayOut[TextTransformation] = core.attr(
+        TextTransformation, kind=core.Kind.array
+    )
+
+    def __init__(
+        self,
+        *,
+        comparison_operator: str | core.StringOut,
+        size: int | core.IntOut,
+        text_transformation: list[TextTransformation] | core.ArrayOut[TextTransformation],
+        field_to_match: FieldToMatch | None = None,
+    ):
+        super().__init__(
+            args=SizeConstraintStatement.Args(
+                comparison_operator=comparison_operator,
+                size=size,
+                text_transformation=text_transformation,
+                field_to_match=field_to_match,
+            ),
+        )
+
+    @core.schema_args
+    class Args(core.SchemaArgs):
+        comparison_operator: str | core.StringOut = core.arg()
+
+        field_to_match: FieldToMatch | None = core.arg(default=None)
+
+        size: int | core.IntOut = core.arg()
+
+        text_transformation: list[TextTransformation] | core.ArrayOut[
+            TextTransformation
+        ] = core.arg()
+
+
 @core.schema
 class SqliMatchStatement(core.Schema):
 
@@ -491,14 +491,10 @@ class SqliMatchStatement(core.Schema):
 
 
 @core.schema
-class ByteMatchStatement(core.Schema):
+class XssMatchStatement(core.Schema):
 
     field_to_match: FieldToMatch | None = core.attr(FieldToMatch, default=None)
 
-    positional_constraint: str | core.StringOut = core.attr(str)
-
-    search_string: str | core.StringOut = core.attr(str)
-
     text_transformation: list[TextTransformation] | core.ArrayOut[TextTransformation] = core.attr(
         TextTransformation, kind=core.Kind.array
     )
@@ -506,15 +502,11 @@ class ByteMatchStatement(core.Schema):
     def __init__(
         self,
         *,
-        positional_constraint: str | core.StringOut,
-        search_string: str | core.StringOut,
         text_transformation: list[TextTransformation] | core.ArrayOut[TextTransformation],
         field_to_match: FieldToMatch | None = None,
     ):
         super().__init__(
-            args=ByteMatchStatement.Args(
-                positional_constraint=positional_constraint,
-                search_string=search_string,
+            args=XssMatchStatement.Args(
                 text_transformation=text_transformation,
                 field_to_match=field_to_match,
             ),
@@ -524,17 +516,13 @@ class ByteMatchStatement(core.Schema):
     class Args(core.SchemaArgs):
         field_to_match: FieldToMatch | None = core.arg(default=None)
 
-        positional_constraint: str | core.StringOut = core.arg()
-
-        search_string: str | core.StringOut = core.arg()
-
         text_transformation: list[TextTransformation] | core.ArrayOut[
             TextTransformation
         ] = core.arg()
 
 
 @core.schema
-class RuleStatementOrStatementStatementNotStatementStatement(core.Schema):
+class RuleStatementNotStatementStatementNotStatementStatement(core.Schema):
 
     byte_match_statement: ByteMatchStatement | None = core.attr(ByteMatchStatement, default=None)
 
@@ -571,7 +559,7 @@ class RuleStatementOrStatementStatementNotStatementStatement(core.Schema):
         xss_match_statement: XssMatchStatement | None = None,
     ):
         super().__init__(
-            args=RuleStatementOrStatementStatementNotStatementStatement.Args(
+            args=RuleStatementNotStatementStatementNotStatementStatement.Args(
                 byte_match_statement=byte_match_statement,
                 geo_match_statement=geo_match_statement,
                 ip_set_reference_statement=ip_set_reference_statement,
@@ -605,88 +593,88 @@ class RuleStatementOrStatementStatementNotStatementStatement(core.Schema):
 
 
 @core.schema
-class RuleStatementOrStatementStatementNotStatement(core.Schema):
+class RuleStatementNotStatementStatementNotStatement(core.Schema):
 
-    statement: list[RuleStatementOrStatementStatementNotStatementStatement] | core.ArrayOut[
-        RuleStatementOrStatementStatementNotStatementStatement
-    ] = core.attr(RuleStatementOrStatementStatementNotStatementStatement, kind=core.Kind.array)
+    statement: list[RuleStatementNotStatementStatementNotStatementStatement] | core.ArrayOut[
+        RuleStatementNotStatementStatementNotStatementStatement
+    ] = core.attr(RuleStatementNotStatementStatementNotStatementStatement, kind=core.Kind.array)
 
     def __init__(
         self,
         *,
-        statement: list[RuleStatementOrStatementStatementNotStatementStatement]
-        | core.ArrayOut[RuleStatementOrStatementStatementNotStatementStatement],
+        statement: list[RuleStatementNotStatementStatementNotStatementStatement]
+        | core.ArrayOut[RuleStatementNotStatementStatementNotStatementStatement],
     ):
         super().__init__(
-            args=RuleStatementOrStatementStatementNotStatement.Args(
+            args=RuleStatementNotStatementStatementNotStatement.Args(
                 statement=statement,
             ),
         )
 
     @core.schema_args
     class Args(core.SchemaArgs):
-        statement: list[RuleStatementOrStatementStatementNotStatementStatement] | core.ArrayOut[
-            RuleStatementOrStatementStatementNotStatementStatement
+        statement: list[RuleStatementNotStatementStatementNotStatementStatement] | core.ArrayOut[
+            RuleStatementNotStatementStatementNotStatementStatement
         ] = core.arg()
 
 
 @core.schema
-class RuleStatementOrStatementStatementOrStatement(core.Schema):
+class RuleStatementNotStatementStatementAndStatement(core.Schema):
 
-    statement: list[RuleStatementOrStatementStatementNotStatementStatement] | core.ArrayOut[
-        RuleStatementOrStatementStatementNotStatementStatement
-    ] = core.attr(RuleStatementOrStatementStatementNotStatementStatement, kind=core.Kind.array)
+    statement: list[RuleStatementNotStatementStatementNotStatementStatement] | core.ArrayOut[
+        RuleStatementNotStatementStatementNotStatementStatement
+    ] = core.attr(RuleStatementNotStatementStatementNotStatementStatement, kind=core.Kind.array)
 
     def __init__(
         self,
         *,
-        statement: list[RuleStatementOrStatementStatementNotStatementStatement]
-        | core.ArrayOut[RuleStatementOrStatementStatementNotStatementStatement],
+        statement: list[RuleStatementNotStatementStatementNotStatementStatement]
+        | core.ArrayOut[RuleStatementNotStatementStatementNotStatementStatement],
     ):
         super().__init__(
-            args=RuleStatementOrStatementStatementOrStatement.Args(
+            args=RuleStatementNotStatementStatementAndStatement.Args(
                 statement=statement,
             ),
         )
 
     @core.schema_args
     class Args(core.SchemaArgs):
-        statement: list[RuleStatementOrStatementStatementNotStatementStatement] | core.ArrayOut[
-            RuleStatementOrStatementStatementNotStatementStatement
+        statement: list[RuleStatementNotStatementStatementNotStatementStatement] | core.ArrayOut[
+            RuleStatementNotStatementStatementNotStatementStatement
         ] = core.arg()
 
 
 @core.schema
-class RuleStatementOrStatementStatementAndStatement(core.Schema):
+class RuleStatementNotStatementStatementOrStatement(core.Schema):
 
-    statement: list[RuleStatementOrStatementStatementNotStatementStatement] | core.ArrayOut[
-        RuleStatementOrStatementStatementNotStatementStatement
-    ] = core.attr(RuleStatementOrStatementStatementNotStatementStatement, kind=core.Kind.array)
+    statement: list[RuleStatementNotStatementStatementNotStatementStatement] | core.ArrayOut[
+        RuleStatementNotStatementStatementNotStatementStatement
+    ] = core.attr(RuleStatementNotStatementStatementNotStatementStatement, kind=core.Kind.array)
 
     def __init__(
         self,
         *,
-        statement: list[RuleStatementOrStatementStatementNotStatementStatement]
-        | core.ArrayOut[RuleStatementOrStatementStatementNotStatementStatement],
+        statement: list[RuleStatementNotStatementStatementNotStatementStatement]
+        | core.ArrayOut[RuleStatementNotStatementStatementNotStatementStatement],
     ):
         super().__init__(
-            args=RuleStatementOrStatementStatementAndStatement.Args(
+            args=RuleStatementNotStatementStatementOrStatement.Args(
                 statement=statement,
             ),
         )
 
     @core.schema_args
     class Args(core.SchemaArgs):
-        statement: list[RuleStatementOrStatementStatementNotStatementStatement] | core.ArrayOut[
-            RuleStatementOrStatementStatementNotStatementStatement
+        statement: list[RuleStatementNotStatementStatementNotStatementStatement] | core.ArrayOut[
+            RuleStatementNotStatementStatementNotStatementStatement
         ] = core.arg()
 
 
 @core.schema
-class RuleStatementOrStatementStatement(core.Schema):
+class RuleStatementNotStatementStatement(core.Schema):
 
-    and_statement: RuleStatementOrStatementStatementAndStatement | None = core.attr(
-        RuleStatementOrStatementStatementAndStatement, default=None
+    and_statement: RuleStatementNotStatementStatementAndStatement | None = core.attr(
+        RuleStatementNotStatementStatementAndStatement, default=None
     )
 
     byte_match_statement: ByteMatchStatement | None = core.attr(ByteMatchStatement, default=None)
@@ -699,12 +687,12 @@ class RuleStatementOrStatementStatement(core.Schema):
 
     label_match_statement: LabelMatchStatement | None = core.attr(LabelMatchStatement, default=None)
 
-    not_statement: RuleStatementOrStatementStatementNotStatement | None = core.attr(
-        RuleStatementOrStatementStatementNotStatement, default=None
+    not_statement: RuleStatementNotStatementStatementNotStatement | None = core.attr(
+        RuleStatementNotStatementStatementNotStatement, default=None
     )
 
-    or_statement: RuleStatementOrStatementStatementOrStatement | None = core.attr(
-        RuleStatementOrStatementStatementOrStatement, default=None
+    or_statement: RuleStatementNotStatementStatementOrStatement | None = core.attr(
+        RuleStatementNotStatementStatementOrStatement, default=None
     )
 
     regex_pattern_set_reference_statement: RegexPatternSetReferenceStatement | None = core.attr(
@@ -722,20 +710,20 @@ class RuleStatementOrStatementStatement(core.Schema):
     def __init__(
         self,
         *,
-        and_statement: RuleStatementOrStatementStatementAndStatement | None = None,
+        and_statement: RuleStatementNotStatementStatementAndStatement | None = None,
         byte_match_statement: ByteMatchStatement | None = None,
         geo_match_statement: GeoMatchStatement | None = None,
         ip_set_reference_statement: IpSetReferenceStatement | None = None,
         label_match_statement: LabelMatchStatement | None = None,
-        not_statement: RuleStatementOrStatementStatementNotStatement | None = None,
-        or_statement: RuleStatementOrStatementStatementOrStatement | None = None,
+        not_statement: RuleStatementNotStatementStatementNotStatement | None = None,
+        or_statement: RuleStatementNotStatementStatementOrStatement | None = None,
         regex_pattern_set_reference_statement: RegexPatternSetReferenceStatement | None = None,
         size_constraint_statement: SizeConstraintStatement | None = None,
         sqli_match_statement: SqliMatchStatement | None = None,
         xss_match_statement: XssMatchStatement | None = None,
     ):
         super().__init__(
-            args=RuleStatementOrStatementStatement.Args(
+            args=RuleStatementNotStatementStatement.Args(
                 and_statement=and_statement,
                 byte_match_statement=byte_match_statement,
                 geo_match_statement=geo_match_statement,
@@ -752,7 +740,9 @@ class RuleStatementOrStatementStatement(core.Schema):
 
     @core.schema_args
     class Args(core.SchemaArgs):
-        and_statement: RuleStatementOrStatementStatementAndStatement | None = core.arg(default=None)
+        and_statement: RuleStatementNotStatementStatementAndStatement | None = core.arg(
+            default=None
+        )
 
         byte_match_statement: ByteMatchStatement | None = core.arg(default=None)
 
@@ -762,9 +752,11 @@ class RuleStatementOrStatementStatement(core.Schema):
 
         label_match_statement: LabelMatchStatement | None = core.arg(default=None)
 
-        not_statement: RuleStatementOrStatementStatementNotStatement | None = core.arg(default=None)
+        not_statement: RuleStatementNotStatementStatementNotStatement | None = core.arg(
+            default=None
+        )
 
-        or_statement: RuleStatementOrStatementStatementOrStatement | None = core.arg(default=None)
+        or_statement: RuleStatementNotStatementStatementOrStatement | None = core.arg(default=None)
 
         regex_pattern_set_reference_statement: RegexPatternSetReferenceStatement | None = core.arg(
             default=None
@@ -777,70 +769,18 @@ class RuleStatementOrStatementStatement(core.Schema):
         xss_match_statement: XssMatchStatement | None = core.arg(default=None)
 
 
-@core.schema
-class RuleStatementOrStatement(core.Schema):
-
-    statement: list[RuleStatementOrStatementStatement] | core.ArrayOut[
-        RuleStatementOrStatementStatement
-    ] = core.attr(RuleStatementOrStatementStatement, kind=core.Kind.array)
-
-    def __init__(
-        self,
-        *,
-        statement: list[RuleStatementOrStatementStatement]
-        | core.ArrayOut[RuleStatementOrStatementStatement],
-    ):
-        super().__init__(
-            args=RuleStatementOrStatement.Args(
-                statement=statement,
-            ),
-        )
-
-    @core.schema_args
-    class Args(core.SchemaArgs):
-        statement: list[RuleStatementOrStatementStatement] | core.ArrayOut[
-            RuleStatementOrStatementStatement
-        ] = core.arg()
-
-
-@core.schema
-class RuleStatementAndStatement(core.Schema):
-
-    statement: list[RuleStatementOrStatementStatement] | core.ArrayOut[
-        RuleStatementOrStatementStatement
-    ] = core.attr(RuleStatementOrStatementStatement, kind=core.Kind.array)
-
-    def __init__(
-        self,
-        *,
-        statement: list[RuleStatementOrStatementStatement]
-        | core.ArrayOut[RuleStatementOrStatementStatement],
-    ):
-        super().__init__(
-            args=RuleStatementAndStatement.Args(
-                statement=statement,
-            ),
-        )
-
-    @core.schema_args
-    class Args(core.SchemaArgs):
-        statement: list[RuleStatementOrStatementStatement] | core.ArrayOut[
-            RuleStatementOrStatementStatement
-        ] = core.arg()
-
-
 @core.schema
 class RuleStatementNotStatement(core.Schema):
 
-    statement: list[RuleStatementOrStatementStatement] | core.ArrayOut[
-        RuleStatementOrStatementStatement
-    ] = core.attr(RuleStatementOrStatementStatement, kind=core.Kind.array)
+    statement: list[RuleStatementNotStatementStatement] | core.ArrayOut[
+        RuleStatementNotStatementStatement
+    ] = core.attr(RuleStatementNotStatementStatement, kind=core.Kind.array)
 
     def __init__(
         self,
         *,
-        statement: list[RuleStatementOrStatementStatement]
-        | core.ArrayOut[RuleStatementOrStatementStatement],
+        statement: list[RuleStatementNotStatementStatement]
+        | core.ArrayOut[RuleStatementNotStatementStatement],
     ):
         super().__init__(
             args=RuleStatementNotStatement.Args(
@@ -850,8 +790,60 @@ class RuleStatementNotStatement(core.Schema):
 
     @core.schema_args
     class Args(core.SchemaArgs):
-        statement: list[RuleStatementOrStatementStatement] | core.ArrayOut[
-            RuleStatementOrStatementStatement
+        statement: list[RuleStatementNotStatementStatement] | core.ArrayOut[
+            RuleStatementNotStatementStatement
+        ] = core.arg()
+
+
+@core.schema
+class RuleStatementAndStatement(core.Schema):
+
+    statement: list[RuleStatementNotStatementStatement] | core.ArrayOut[
+        RuleStatementNotStatementStatement
+    ] = core.attr(RuleStatementNotStatementStatement, kind=core.Kind.array)
+
+    def __init__(
+        self,
+        *,
+        statement: list[RuleStatementNotStatementStatement]
+        | core.ArrayOut[RuleStatementNotStatementStatement],
+    ):
+        super().__init__(
+            args=RuleStatementAndStatement.Args(
+                statement=statement,
+            ),
+        )
+
+    @core.schema_args
+    class Args(core.SchemaArgs):
+        statement: list[RuleStatementNotStatementStatement] | core.ArrayOut[
+            RuleStatementNotStatementStatement
+        ] = core.arg()
+
+
+@core.schema
+class RuleStatementOrStatement(core.Schema):
+
+    statement: list[RuleStatementNotStatementStatement] | core.ArrayOut[
+        RuleStatementNotStatementStatement
+    ] = core.attr(RuleStatementNotStatementStatement, kind=core.Kind.array)
+
+    def __init__(
+        self,
+        *,
+        statement: list[RuleStatementNotStatementStatement]
+        | core.ArrayOut[RuleStatementNotStatementStatement],
+    ):
+        super().__init__(
+            args=RuleStatementOrStatement.Args(
+                statement=statement,
+            ),
+        )
+
+    @core.schema_args
+    class Args(core.SchemaArgs):
+        statement: list[RuleStatementNotStatementStatement] | core.ArrayOut[
+            RuleStatementNotStatementStatement
         ] = core.arg()
 
 
@@ -950,6 +942,39 @@ class RuleStatement(core.Schema):
         xss_match_statement: XssMatchStatement | None = core.arg(default=None)
 
 
+@core.schema
+class VisibilityConfig(core.Schema):
+
+    cloudwatch_metrics_enabled: bool | core.BoolOut = core.attr(bool)
+
+    metric_name: str | core.StringOut = core.attr(str)
+
+    sampled_requests_enabled: bool | core.BoolOut = core.attr(bool)
+
+    def __init__(
+        self,
+        *,
+        cloudwatch_metrics_enabled: bool | core.BoolOut,
+        metric_name: str | core.StringOut,
+        sampled_requests_enabled: bool | core.BoolOut,
+    ):
+        super().__init__(
+            args=VisibilityConfig.Args(
+                cloudwatch_metrics_enabled=cloudwatch_metrics_enabled,
+                metric_name=metric_name,
+                sampled_requests_enabled=sampled_requests_enabled,
+            ),
+        )
+
+    @core.schema_args
+    class Args(core.SchemaArgs):
+        cloudwatch_metrics_enabled: bool | core.BoolOut = core.arg()
+
+        metric_name: str | core.StringOut = core.arg()
+
+        sampled_requests_enabled: bool | core.BoolOut = core.arg()
+
+
 @core.schema
 class InsertHeader(core.Schema):
 
@@ -1164,27 +1189,6 @@ class Action(core.Schema):
         count: Count | None = core.arg(default=None)
 
 
-@core.schema
-class RuleLabel(core.Schema):
-
-    name: str | core.StringOut = core.attr(str)
-
-    def __init__(
-        self,
-        *,
-        name: str | core.StringOut,
-    ):
-        super().__init__(
-            args=RuleLabel.Args(
-                name=name,
-            ),
-        )
-
-    @core.schema_args
-    class Args(core.SchemaArgs):
-        name: str | core.StringOut = core.arg()
-
-
 @core.schema
 class Rule(core.Schema):
 
